@@ -15,20 +15,19 @@
 # The University of Texas at Austin
 # Austin, Texas  78712
 #
-# whatis-1.3 aeb 940331
+# whatis-1.4d aeb 950220
 #
 
+OLDPATH=$PATH
 PATH=/usr/local/bin:/bin:/usr/ucb:/usr/bin
 
-libdir=%libdir%
-
 if [ $# = 0 ]
 then
     echo "usage: `basename $0` name ..."
     exit 1
 fi
 
-manpath=`%bindir%/man --path | tr : '\040'`
+manpath=`(PATH=$OLDPATH; %bindir%/man %manpathoption%) | tr : '\040'`
 
 if [ "$manpath" = "" ]
 then
@@ -41,24 +40,57 @@ then
     PAGER="%pager%"
 fi
 
+# avoid using a pager if only output is "nothing appropriate"
+nothing=
+found=0
+while [ $found = 0 -a -n "$1" ]
+do
+    for d in $manpath /usr/lib
+    do
+        if [ -f $d/whatis ]
+        then
+            if grep -iw%grepsilent% "^$1" $d/whatis > /dev/null
+            then
+                found=1
+            fi
+        fi
+    done
+    if [ $found = 0 ]
+    then
+	nothing="$nothing $1"
+	shift
+    fi
+done
+
+if [ $found = 0 ]
+then
+    for i in $nothing
+    do
+	echo "$i: nothing appropriate"
+    done
+    exit
+fi
+
 while [ $1 ]
 do
+    for i in $nothing
+    do
+	echo "$i: nothing appropriate"
+    done
+    nothing=
     found=0
     for d in $manpath /usr/lib
     do
         if [ -f $d/whatis ]
         then
-            grep -iw "^$1" $d/whatis
-            status=$?
-            if [ "$status" = "0" ]
+            if grep -iw "^$1" $d/whatis
             then
                 found=1
-		export found
             fi
         fi
     done
 
-    if [ "$found" = "0" ]
+    if [ $found = 0 ]
     then
         echo "$1: nothing appropriate"
     fi
